@@ -115,11 +115,7 @@ cad.UPb <- function(x,pch=NA,verticals=TRUE,xlab='age [Ma]',
                     col='black',type=4,cutoff.76=1100,
                     cutoff.disc=c(-15,5),common.Pb=0,
                     hide=NULL,...){
-    if (common.Pb %in% c(1,2,3))
-        X <- common.Pb.correction(x,option=common.Pb)
-    else
-        X <- x
-    tt <- filter.UPb.ages(X,type,cutoff.76,cutoff.disc)[,1]
+    tt <- filter.UPb.ages(x,type,cutoff.76,cutoff.disc,common.Pb=common.Pb)[,1]
     cad.default(tt,pch=pch,verticals=verticals,xlab=xlab,
                 col=col,hide=hide,...)
 }
@@ -143,11 +139,7 @@ cad.UPb <- function(x,pch=NA,verticals=TRUE,xlab='age [Ma]',
 #' @export
 cad.PbPb <- function(x,pch=NA,verticals=TRUE,xlab='age [Ma]',
                      col='black',common.Pb=1,hide=NULL,...){
-    if (common.Pb %in% c(1,2,3))
-        X <- common.Pb.correction(x,option=common.Pb)
-    else
-        X <- x
-    tt <- PbPb.age(X)[,1]
+    tt <- PbPb.age(x,common.Pb=common.Pb)[,1]
     cad.default(tt,pch=pch,verticals=verticals,xlab=xlab,
                 col=col,hide=hide,...)
 }
@@ -168,7 +160,7 @@ cad.KCa <- function(x,pch=NA,verticals=TRUE,xlab='age [Ma]',
                 col=col,hide=hide,...)
 }
 #' @param detritus detrital \eqn{^{230}}Th correction (only applicable
-#'     when \code{x$format == 1} or \code{2}.
+#'     when \code{x$format == 1} or \code{2}).
 #'
 #' \code{0}: no correction
 #'
@@ -181,21 +173,11 @@ cad.KCa <- function(x,pch=NA,verticals=TRUE,xlab='age [Ma]',
 #' \eqn{^{230}}Th/\eqn{^{238}}U, \eqn{^{232}}Th/\eqn{^{238}}U and
 #' \eqn{^{234}}U/\eqn{^{238}}U-ratios in the detritus.
 #'
-#' @param Th02 2-element vector with the assumed initial
-#'     \eqn{^{230}}Th/\eqn{^{232}}Th-ratio of the detritus and its
-#'     standard error. Only used if \code{detritus==2}
-#' @param Th02U48 9-element vector with the measured composition of
-#'     the detritus, containing \code{X=0/8}, \code{sX}, \code{Y=2/8},
-#'     \code{sY}, \code{Z=4/8}, \code{sZ}, \code{rXY}, \code{rXZ},
-#'     \code{rYZ}. Only used if \code{isochron==FALSE} and
-#'     \code{detritus==3}
 #' @rdname cad
 #' @export
 cad.ThU <- function(x,pch=NA,verticals=TRUE, xlab='age [ka]',
-                    col='black',i2i=FALSE,detritus=0,Th02=c(0,0),
-                    Th02U48=c(0,0,1e6,0,0,0,0,0,0),hide=NULL,...){
-    tt <- ThU.age(x,i2i=i2i,detritus=detritus,
-                  Th02=Th02,Th02U48=Th02U48)[,1]
+                    col='black',i2i=FALSE,detritus=0,hide=NULL,...){
+    tt <- ThU.age(x,i2i=i2i,detritus=detritus)[,1]
     cad.default(tt,pch=pch,verticals=verticals,xlab=xlab,
                 col=col,hide=hide,...)
 }
